/******************************************************************************
 *                                                                            *
 * File:   clip-txt.c          Version  1.00            Date: 2000-06-02      *
 *                                                                            *
 * Copyright (C) 2000 by Kostis Netzwerkberatung                              *
 * Talstr. 25, D-63322 Rdermark, Tel. +49 6074 881056, FAX 881058            *
 * kosta@kostis.net (Kosta Kostis), http://www.kostis.net/                    *
 *                                                                            *
 ******************************************************************************
 *                                                                            *
 * Function:                                                                  *
 *        - copy text input from stdin to clipboard (max. 64 KB)              *
 *                                                                            *
 ******************************************************************************
 *                                                                            *
 * History:                                                                   *
 *     2000-06-02: KK V1.00                                                   *
 *        - initial encoding                                                  *
 *                                                                            *
 *****************************************************************************/

#include <windows.h>
#include <winuser.h>
#include <stdio.h>
#include <string.h>

#include "clip-txt.h"

/******************************************************************************

	Function:
		display copyright, author and program information

	Parameters:
		none

	Returns:
		nothing

 *****************************************************************************/

static  void    Hello (void)
{
	fprintf (stderr, MSG_COPYRIGHT) ;
	fprintf (stderr, MSG_VERSION, PRGNAM, VERSION) ;
}

/******************************************************************************

	main program

 *****************************************************************************/

int     main
(
	int     	argc,
	char		*argv	[]
)
{
	HGLOBAL		textfile ;
	HANDLE		Fin ;
	DWORD		bytes ;
	HWND		hWnd ;

	/**********************************************************************

		parse parameters/arguments

	 *********************************************************************/

	if (argc != 1)
	{
		/**************************************************************

			display syntax error message and quit

		 *************************************************************/

		Hello () ;
		fprintf (stderr, ERR_MSG_SYNTAX, PRGNAM) ;

		return (ERR_SYNTAX) ;
	}

	/**********************************************************************

		allocate global memory for clipboard content (do not free)

	 *********************************************************************/

	textfile = GlobalAlloc (GMEM_NOCOMPACT | GMEM_ZEROINIT, MAX_CLIPBOARD_LEN + 1) ;
	if (textfile == (HGLOBAL) NULL)
	{
		printf (ERR_MSG_MEMORY, PRGNAM) ;
		return (ERR_MEMORY) ;
	}

	/**********************************************************************

		get stdin handle

	 *********************************************************************/

	Fin = GetStdHandle (STD_INPUT_HANDLE) ;

	/**********************************************************************

		read text from stdin into memory

	 *********************************************************************/

	ReadFile (Fin, textfile, MAX_CLIPBOARD_LEN, &bytes, (LPOVERLAPPED) NULL) ;

	/**********************************************************************

		copy text read into clipboard

	 *********************************************************************/

	hWnd = GetDesktopWindow () ;
	if (hWnd != (HWND) NULL)
	{
		OpenClipboard (hWnd) ;
		EmptyClipboard () ;
		SetClipboardData (CF_TEXT, textfile) ;
		CloseClipboard () ;
	}

	/**********************************************************************

		terminate *without* freeing memory previously allocated

	 *********************************************************************/

	return (ERR_NONE) ;
}
